<!DOCTYPE TS><TS>
<context>
    <name>AddMeta</name>
    <message>
        <source>Insert a:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice &amp;Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log C&amp;hain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditChain</name>
    <message>
        <source>Edit Log Chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditLog</name>
    <message>
        <source>Edit Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Origin:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AutoRefresh:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Date Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Date Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert
Meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save
&amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This log contains one or more carts
that are invalid for the selected service!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!

Do you still want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The log has been modified.
Do you want to save your changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[INVALID CART]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to save log, audio deletion error!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditLogLine</name>
    <message>
        <source>Edit Log Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must supply a cart number!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart belongs to a disabled
group for the specified service!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMarker</name>
    <message>
        <source>Edit Log Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Listing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Exception Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Effective Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOG NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MUSIC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRAFFIC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACKS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VALID FROM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VALID TO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AUTO REFRESH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LAST LINKED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LAST MODIFIED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice
&amp;Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TFN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete log, audio deletion error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This version of RDLogEdit is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VoiceTracker</name>
    <message>
        <source>Voice Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Cue Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo Segue Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Start Point Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set End Point Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set to Hook Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Previous
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do Over</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hit Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No VoiceTrack Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No voicetracking group has been defined for this service,
therefore only existing transitions will be editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Creation Failure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create new cart for voice track!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Deletion Error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No more tracks!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[end of log]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save segue changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit - Voice Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALBUM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
